@@ -3,12 +3,14 @@
 import jax
 import time
 import jax.numpy as jnp
+from .stacking import write_cache
 from ..utilities.jacobian import get_stst_jacobian
-from ..parser.checks import check_if_compiled, write_compiled_objects
+from ..parser import d2jnp
+from ..parser.checks import check_if_compiled
 from ..parser.build_functions import build_aggr_het_agent_funcs, get_stst_derivatives
 
 
-def find_path_linear(model, shock=None, init_state=None, parameters=None, horizon=200, verbose=True):
+def find_path_linear(model, shock=None, init_state=None, pars=None, horizon=200, verbose=True):
     """Find the linear expected trajectory given an initial state.
 
     Parameters
@@ -17,7 +19,7 @@ def find_path_linear(model, shock=None, init_state=None, parameters=None, horizo
         PizzaModel instance
     init_state : array
         initial state
-    parameters : dict, optional
+    pars : dict, optional
         alternative parameters. Warning: do only change those parameters that are invariant to the steady state.
     shock : tuple, optional
         shock in period 0 as in `(shock_name_as_str, shock_size)`. NOTE: Not (yet) implemented.
@@ -45,10 +47,9 @@ def find_path_linear(model, shock=None, init_state=None, parameters=None, horizo
     st = time.time()
 
     # get model variables
-    stst = jnp.array(list(model['stst'].values()))
+    stst = d2jnp(model['stst'])
     nvars = len(model["variables"])
-    pars = jnp.array(
-        list((parameters if parameters is not None else model["parameters"]).values()))
+    pars = d2jnp((pars if pars is not None else model["pars"]))
     shocks = model.get("shocks") or ()
     x_stst = jnp.ones((horizon + 1, nvars)) * stst
 
@@ -57,18 +58,18 @@ def find_path_linear(model, shock=None, init_state=None, parameters=None, horizo
 
     x0 = jnp.array(list(init_state)) if init_state is not None else stst
 
-    if not check_if_compiled(model, horizon, pars):
+    if not check_if_compiled(model, horizon, pars, stst):
         # get derivatives via AD and compile functions
-        build_aggr_het_agent_funcs(
-            model, nvars, pars, stst, zero_shocks, horizon)
+        build_aggr_het_agent_funcs(model, jnp.zeros_like(
+            pars), nvars, stst, zero_shocks, horizon)
         derivatives = get_stst_derivatives(
             model, nvars, pars, stst, x_stst, zero_shocks, horizon, verbose)
 
         # accumulate steady stat jacobian
         get_stst_jacobian(model, derivatives, horizon, nvars, verbose)
-        write_compiled_objects(model, horizon, pars)
+        write_cache(model, horizon, pars, stst)
 
-    jacobian = model['jac']
+    jacobian = model['cache']['jac']
 
     x0 -= stst
     x = - \
