@@ -5,20 +5,29 @@ import jax
 import time
 import jax.numpy as jnp
 from grgrjax import val_and_jacrev
+from ..parser import d2jnp
 from ..parser.build_functions import build_aggr_het_agent_funcs, get_stst_derivatives
-from ..parser.checks import check_if_compiled, write_compiled_objects
+from ..parser.checks import check_if_compiled
 from ..utilities.jacobian import get_stst_jacobian, get_jac_and_value_sliced
 from ..utilities.newton import newton_for_jvp, newton_for_banded_jac, newton_jax_jit_wrapper
 
 
+def write_cache(model, horizon, pars, stst):
+    model['cache']['horizon'] = horizon
+    model['cache']['pars'] = pars
+    model['cache']['stst'] = stst
+    return
+
+
 def find_path_stacking(
     model,
     shock=None,
     init_state=None,
     init_dist=None,
-    parameters=None,
+    pars=None,
     horizon=200,
     use_solid_solver=False,
+    skip_jacobian=False,
     verbose=True,
     raise_errors=True,
     **newton_args
@@ -35,10 +44,12 @@ def find_path_stacking(
         tial state
     init_dist : array, optional
         tial distribution
-    parameters : dict, optional
+    pars : dict, optional
         alternative parameters. Warning: do only change those parameters that are invariant to the steady state.
     horizon : int, optional
         number of periods until the system is assumed to be back in the steady state. Defaults to 200
+    skip_jacobian : bool, optional
+        whether to skip the calculation of the steady state sequence space Jacobian. If True, the last cached Jacobian will be used. Defaults to False
     verbose : bool, optional
         degree of verbosity. 0/`False` is silent
     raise_errors : bool, optional
@@ -55,12 +66,14 @@ def find_path_stacking(
     """
 
     st = time.time()
+    # only skip jacobian calculation if it exists
+    skip_jacobian = skip_jacobian if model['cache'].get(
+        'jac_factorized') else False
 
     # get variables
-    stst = jnp.array(list(model["stst"].values()))
+    stst = d2jnp(model["stst"])
     nvars = len(model["variables"])
-    pars = jnp.array(
-        list((parameters if parameters is not None else model["parameters"]).values()))
+    pars = d2jnp(pars if pars is not None else model["pars"])
     shocks = model.get("shocks") or ()
 
     # get initial guess
@@ -81,42 +94,42 @@ def find_path_stacking(
 
     if not model.get('distributions'):
 
-        if not check_if_compiled(model, horizon, pars):
+        if not check_if_compiled(model, horizon, pars, stst) or not model['context'].get('jav_func'):
             # get transition function
             func_eqns = model['context']["func_eqns"]
             jav_func_eqns = val_and_jacrev(func_eqns, (0, 1, 2))
             jav_func_eqns_partial = jax.tree_util.Partial(
                 jav_func_eqns, XSS=stst, pars=pars, distributions=[], decisions_outputs=[])
-            model['jav_func'] = jav_func_eqns_partial
+            model['context']['jav_func'] = jav_func_eqns_partial
             # mark as compiled
-            write_compiled_objects(model, horizon, pars)
+            write_cache(model, horizon, pars, stst)
 
         # actual newton iterations
-        jav_func_eqns_partial = model['jav_func']
+        jav_func_eqns_partial = model['context']['jav_func']
         x_out, flag, mess = newton_for_banded_jac(
             jav_func_eqns_partial, nvars, horizon, x_init, shock_series, verbose, **newton_args)
 
     else:
-        if not check_if_compiled(model, horizon, pars):
+        if not check_if_compiled(model, horizon, pars, stst) or not model['context'].get('jvp_func'):
             # get derivatives via AD and compile functions
             zero_shocks = jnp.zeros_like(shock_series).T
-            build_aggr_het_agent_funcs(
-                model, nvars, pars, stst, zero_shocks, horizon)
+            build_aggr_het_agent_funcs(model, jnp.zeros_like(
+                pars), nvars, stst, zero_shocks, horizon)
 
-            if not use_solid_solver:
+            if not use_solid_solver and not skip_jacobian:
                 # get steady state partial jacobians
                 derivatives = get_stst_derivatives(
                     model, nvars, pars, stst, x_stst, zero_shocks, horizon, verbose)
                 # accumulate steady stat jacobian
                 get_stst_jacobian(model, derivatives, horizon, nvars, verbose)
             # mark as compiled
-            write_compiled_objects(model, horizon, pars)
+            write_cache(model, horizon, pars, stst)
 
         # get jvp function and steady state jacobian
         jvp_partial = jax.tree_util.Partial(
-            model['context']['jvp_func'], x0=x0, dist0=dist0, shocks=shock_series.T)
+            model['context']['jvp_func'], x0=x0, dist0=dist0, shocks=shock_series.T, pars=pars)
         if not use_solid_solver:
-            jacobian = model['jac_factorized']
+            jacobian = model['cache']['jac_factorized']
             # actual newton iterations
             x, flag, mess = newton_for_jvp(
                 jvp_partial, jacobian, x_init, verbose, **newton_args)
